Changelog
=========

3.1.1 (2021-02-16)
------------------

- Correction d'un lien sur le primer d'Orvar
- Ajout du pseudo de Soulessoni


3.1.0 (2021-02-16)
------------------

- Ajout d'un article sur la complexité mathématique de Magic 1/4
- Ajout d'un article sur la complexité mathématique de Magic 2/4
- Ajout d'un primer sur Orvar, the All-Form


3.0.5 (2021-02-12)
------------------

- Ajout d'un lien vers les livres de Patrick Chapin
- Corrections dans le footer


3.0.4 (2021-02-08)
------------------

- Corrections sur l'article sur la méthode de deckbuilding


3.0.3 (2021-02-07)
------------------

- Ajout d'un article sur la méthode de deckbuilding
- Modification de carte "identité" pour certains articles
- Améliorations cosmétiques


3.0.2 (2021-02-03)
------------------

- Amélioration de la génération des decklists
- Amélioration de l'affichage de l'analyse de Winota
- Amélioration de l'affichage des deckslists
- Mise à jour des listes et indication des dates de publication
- Amélioration de l'affichage des titres des articles


3.0.1 (2021-02-02)
------------------

- Modification de carte "identité" pour certains articles
- Modification du ratio d'affichage des decklists


3.0.0 (2021-02-02)
------------------

- Modification de la navigation dans les articles
- Modification de l'apparence des sections
- Remplacement de la bannière
- Mise à jour de la page d'accueil
- Nouvelle apparence
- Suppression de l'affichage au clic
- Ajout de Popper/Tippy pour l'affichage des cartes (1/2)
- Ajout de Popper/Tippy pour l'affichage des cartes (2/2)
- Modification de l'affichage des decklists
- Correction du display des cartes dans les articles
- Correction du display des cartes dans les pages "portfolio"


2.4.1 (2021-02-02)
------------------

- Mise à jour du sitemap
- Ajout d'une présentation de Kelsien


2.4.0 (2021-01-26)
------------------

- Ajout d'une présentation d'Adeliz
- Ajout d'une présentation de Golos


2.3.1 (2021-01-24)
------------------

- Corrections dans la définition des archétypes
- Corrections dans l'analyse d'Isamaru


2.3.0 (2021-01-24)
------------------

- Preloading style and core script for faster rendering
- Preloading decklist rendering
- Fixing hover issue in articles


2.2.0 (2021-01-24)
------------------

- Ajout de trois review sur des decks du Codex
- Fix présentation pour prochaine section
- Ajout d'une review rapide de Isamaru


2.1.0 (2021-01-23)
------------------

- Fix nom de certaines pages
- Correction page "archétypes"
- Fix un lien
- Ajout d'une review rapide de Venser


2.0.12 (2021-01-23)
-------------------

- Fix de la page "Cartes thématiques"
- Retrait de l'image manquante pour zombie33


2.0.11 (2021-01-18)
-------------------

- Ajout disclaimer page Archétypes


2.0.10 (2021-01-17)
-------------------

- Ajout d'une cartouche wip dans section archetype
- Ajout d'une liste de Adeliz, the Cinder Wind
- Ajout d'une liste de Aminatou, the Fateshifter
- Ajout d'une liste de Golos, Tireless Pilgrim
- Ajout d'une liste de The Gitrog Monster
- Ajout d'une liste de Titania, Protector of Argoth


2.0.9 (2021-01-16)
------------------

- Ajout de la page sur les bounces
- Ajout de la page sur les cantrips
- MAJ liste de Winota vers version 5.1
- Ajout de 3 decklistes


2.0.8 (2021-01-07)
------------------

- Fix card display in decklists


2.0.7 (2021-01-07)
------------------

- Upgrade win-o-math calculator
- Ajout présentation rapide de Winota


2.0.6 (2021-01-07)
------------------

- Fix decklist converter
- Fix Winota decklist


2.0.5 (2021-01-07)
------------------

- Update robots.txt


2.0.4 (2021-01-06)
------------------

- Ajout des Win-o-Maths


2.0.3 (2021-01-06)
------------------

- Fix Manifest


2.0.2 (2021-01-06)
------------------

- Fix favicon


2.0.1 (2021-01-06)
------------------

- Fix title index.html


2.0.0 (2021-01-06)
------------------

- Retrait des sets "Secret Lair", "Master" et "Funny"
- Ajout des titres de page différenciés


1.2.7 (2021-01-06)
------------------

- Fixed backend problem (wrong permission on vps folder)
- Back to 1.2.4


1.2.6 (2021-01-06)
------------------

- library.json.gz


1.2.5 (2021-01-06)
------------------

- Send library.json.gz


1.2.4 (2021-01-06)
------------------

- Écriture de la page grosses créatures
- Suppression d'une fonction en doublon dans le backend


1.2.3 (2021-01-04)
------------------

- Ajout robots.txt
- Ajout sitemap.xml
- Ajout d'une méthode pour les servir directement


1.2.2 (2021-01-04)
------------------

- Ajout d'un paragraphe sur les enchants à mana dans ramp
- Ajout d'un paragraphe sur les enchants à mana dans dorks
- Retrait du tip dans l'analyse de Kess
- Ajout d'une balise `<meta name="robots" content="all">` pour le data crawling


1.2.1 (2021-01-04)
------------------

- Corrections de l'outil analytique


1.2.0 (2021-01-04)
------------------

- Ajout outil analytique


1.1.1 (2021-01-04)
------------------

- Espacement entre paragraphes
- Correction de la page "ramp"


1.1.0 (2021-01-04)
------------------

- Correction des couleurs des decklists "light"
- Correction de l'espacement des cartes thématiques
- Changement de l'entrée "la recherche de créatures" par "les mana dorks"
- Rédaction de la page de ramp
- Rédaction de la page de mana dork


1.0.1 (2021-01-03)
------------------

- Fix og_description


1.0.0 (2021-01-03)
------------------

- Site en beta
